colour_hdri.process — Colour - HDRI 0.1.0 documentation

# Source code for colour_hdri.process

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .conversion import (
        RAW_CONVERTER,
        RAW_CONVERSION_ARGUMENTS,
        RAW_D_CONVERSION_ARGUMENTS,
        DNG_CONVERTER,
        DNG_CONVERSION_ARGUMENTS,
        convert_raw_files_to_dng_files,
        convert_dng_files_to_intermediate_files)

    __all__ = [
        'RAW_CONVERTER',
        'RAW_CONVERSION_ARGUMENTS',
        'RAW_D_CONVERSION_ARGUMENTS',
        'DNG_CONVERTER',
        'DNG_CONVERSION_ARGUMENTS',
        'convert_raw_files_to_dng_files',
        'convert_dng_files_to_intermediate_files']